@@ -401,11 +401,11 @@ sensitize_widgets (TaskPage *tpage)
 		GTK_EDITABLE (priv->web_page_entry), !read_only);
 
 	gtk_widget_set_sensitive (priv->organizer, !read_only);
-	gtk_widget_set_sensitive (priv->add, (!read_only &&  sens));
+	gtk_widget_set_sensitive (priv->add, (!read_only && sens));
 	gtk_widget_set_sensitive (priv->edit, (!read_only && sens));
 	e_meeting_list_view_set_editable (priv->list_view, (!read_only && sens));
-	gtk_widget_set_sensitive (priv->remove, (!read_only &&  sens));
-	gtk_widget_set_sensitive (priv->invite, (!read_only &&  sens));
+	gtk_widget_set_sensitive (priv->remove, (!read_only && sens));
+	gtk_widget_set_sensitive (priv->invite, (!read_only && sens));
 	gtk_widget_set_sensitive (GTK_WIDGET (priv->list_view), !read_only);
 
 	action_group = comp_editor_get_action_group (editor, "editable");
@@ -2673,10 +2673,12 @@ task_page_construct (TaskPage *tpage,
 
 	/* Make sure our custom widget classes are registered with
 	 * GType before we load the GtkBuilder definition file. */
+	g_type_ensure (E_TYPE_CLIENT_COMBO_BOX);
 	g_type_ensure (E_TYPE_DATE_EDIT);
 	g_type_ensure (E_TYPE_TIMEZONE_ENTRY);
 	g_type_ensure (E_TYPE_SOURCE_COMBO_BOX);
 	g_type_ensure (E_TYPE_SPELL_ENTRY);
+	g_type_ensure (E_TYPE_URL_ENTRY);
 
 	priv->builder = gtk_builder_new ();
 	e_load_ui_builder_definition (priv->builder, "task-page.ui");
