@@ -167,8 +167,6 @@ setup_e_table (ECalListView *cal_list_view)
 	ETableSpecification *specification;
 	GList *strings;
 	ECell *cell, *popup_cell;
-	GnomeCanvas *canvas;
-	GtkStyle *style;
 	GtkWidget *container;
 	GtkWidget *widget;
 	gchar *etspecfile;
@@ -302,15 +300,6 @@ setup_e_table (ECalListView *cal_list_view)
 	g_object_unref (specification);
 	g_free (etspecfile);
 
-	/* Make sure text is readable on top of our color coding */
-
-	canvas = GNOME_CANVAS (cal_list_view->table->table_canvas);
-	style = gtk_widget_get_style (GTK_WIDGET (canvas));
-
-	style->fg[GTK_STATE_SELECTED] = style->text[GTK_STATE_NORMAL];
-	style->fg[GTK_STATE_ACTIVE]   = style->text[GTK_STATE_NORMAL];
-	gtk_widget_set_style (GTK_WIDGET (canvas), style);
-
 	/* Connect signals */
 	g_signal_connect (
 		cal_list_view->table, "double_click",
@@ -324,7 +313,7 @@ setup_e_table (ECalListView *cal_list_view)
 		cal_list_view->table, "cursor_change",
 		G_CALLBACK (e_cal_list_view_cursor_change_cb),
 		cal_list_view);
-	g_signal_connect_after (
+	e_signal_connect_notify_after (
 		cal_list_view->table, "notify::is-editing",
 		G_CALLBACK (e_cal_list_view_table_editing_changed_cb),
 		cal_list_view);
