@@ -66,6 +66,8 @@ emfe_text_enriched_format (EMailFormatterExtension *extension,
 
 	filter = camel_mime_filter_enriched_new (filter_flags);
 	filtered_stream = camel_filter_output_stream_new (stream, filter);
+	g_filter_output_stream_set_close_base_stream (
+		G_FILTER_OUTPUT_STREAM (filtered_stream), FALSE);
 	g_object_unref (filter);
 
 	string =
