@@ -489,20 +489,21 @@ mail_formatter_update_style (EMailFormatter *formatter,
 	GtkStyleContext *style_context;
 	GtkWidgetPath *widget_path;
 	GdkRGBA rgba;
+	gboolean backdrop;
 
 	g_object_freeze_notify (G_OBJECT (formatter));
 
-	/* derive colors from top-level window */
 	style_context = gtk_style_context_new ();
 	widget_path = gtk_widget_path_new ();
 	gtk_widget_path_append_type (widget_path, GTK_TYPE_WINDOW);
 	gtk_style_context_set_path (style_context, widget_path);
-	gtk_style_context_invalidate (style_context);
+	backdrop = (state & GTK_STATE_FLAG_BACKDROP) != 0;
 
-	gtk_style_context_save (style_context);
-	gtk_style_context_add_class (style_context, GTK_STYLE_CLASS_TOOLBAR);
-
-	gtk_style_context_get_background_color (style_context, state, &rgba);
+	if (!gtk_style_context_lookup_color (
+			style_context,
+			backdrop ? "theme_unfocused_bg_color" : "theme_bg_color",
+			&rgba))
+		gdk_rgba_parse (&rgba, E_UTILS_DEFAULT_THEME_BG_COLOR);
 	e_mail_formatter_set_color (
 		formatter, E_MAIL_FORMATTER_COLOR_BODY, &rgba);
 
@@ -512,20 +513,27 @@ mail_formatter_update_style (EMailFormatter *formatter,
 	e_mail_formatter_set_color (
 		formatter, E_MAIL_FORMATTER_COLOR_FRAME, &rgba);
 
-	gtk_style_context_restore (style_context);
-	gtk_style_context_add_class (style_context, GTK_STYLE_CLASS_ENTRY);
-
-	gtk_style_context_get_color (style_context, state, &rgba);
+	if (!gtk_style_context_lookup_color (
+			style_context,
+			backdrop ? "theme_unfocused_fg_color" : "theme_fg_color",
+			&rgba))
+		gdk_rgba_parse (&rgba, E_UTILS_DEFAULT_THEME_FG_COLOR);
 	e_mail_formatter_set_color (
 		formatter, E_MAIL_FORMATTER_COLOR_HEADER, &rgba);
 
-	gtk_style_context_get_background_color (
-		style_context, state | GTK_STATE_FLAG_FOCUSED, &rgba);
+	if (!gtk_style_context_lookup_color (
+			style_context,
+			backdrop ? "theme_unfocused_base_color" : "theme_base_color",
+			&rgba))
+		gdk_rgba_parse (&rgba, E_UTILS_DEFAULT_THEME_BASE_COLOR);
 	e_mail_formatter_set_color  (
 		formatter, E_MAIL_FORMATTER_COLOR_CONTENT, &rgba);
 
-	gtk_style_context_get_color (
-		style_context, state | GTK_STATE_FLAG_FOCUSED, &rgba);
+	if (!gtk_style_context_lookup_color (
+			style_context,
+			backdrop ? "theme_unfocused_fg_color" : "theme_fg_color",
+			&rgba))
+		gdk_rgba_parse (&rgba, E_UTILS_DEFAULT_THEME_FG_COLOR);
 	e_mail_formatter_set_color (
 		formatter, E_MAIL_FORMATTER_COLOR_TEXT, &rgba);
 
@@ -605,7 +613,7 @@ e_mail_formatter_class_init (EMailFormatterClass *class)
 	gdk_rgba_parse (rgba, "#3f3f3f");
 
 	rgba = &class->colors[E_MAIL_FORMATTER_COLOR_HEADER];
-	gdk_rgba_parse (rgba, "#eeeeee");
+	gdk_rgba_parse (rgba, "#000000");
 
 	rgba = &class->colors[E_MAIL_FORMATTER_COLOR_TEXT];
 	gdk_rgba_parse (rgba, "#000000");
@@ -1065,6 +1073,8 @@ e_mail_formatter_format_text (EMailFormatter *formatter,
 		windows = camel_mime_filter_windows_new (charset);
 		filter_stream = camel_filter_output_stream_new (
 			null_stream, windows);
+		g_filter_output_stream_set_close_base_stream (
+			G_FILTER_OUTPUT_STREAM (filter_stream), FALSE);
 
 		camel_data_wrapper_decode_to_output_stream_sync (
 			CAMEL_DATA_WRAPPER (mime_part),
@@ -1083,6 +1093,8 @@ e_mail_formatter_format_text (EMailFormatter *formatter,
 	filter = camel_mime_filter_charset_new (charset, "UTF-8");
 	if (filter != NULL) {
 		stream = camel_filter_output_stream_new (stream, filter);
+		g_filter_output_stream_set_close_base_stream (
+			G_FILTER_OUTPUT_STREAM (stream), FALSE);
 		g_object_unref (filter);
 	} else {
 		g_object_ref (stream);
