@@ -1,18 +1,17 @@
 /*
  * e-mail-reader-utils.h
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) version 3.
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
@@ -92,7 +91,8 @@ void		e_mail_reader_parse_message	(EMailReader *reader,
 						 gpointer user_data);
 EMailPartList *	e_mail_reader_parse_message_finish
 						(EMailReader *reader,
-						 GAsyncResult *result);
+						 GAsyncResult *result,
+						 GError **error);
 
 G_END_DECLS
 
