@@ -1,18 +1,17 @@
 /*
  * e-memo-shell-view-private.c
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) version 3.
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
@@ -144,7 +143,7 @@ memo_shell_view_notify_view_id_cb (EShellView *shell_view)
 void
 e_memo_shell_view_private_init (EMemoShellView *memo_shell_view)
 {
-	g_signal_connect (
+	e_signal_connect_notify (
 		memo_shell_view, "notify::view-id",
 		G_CALLBACK (memo_shell_view_notify_view_id_cb), NULL);
 }
