@@ -56,8 +56,7 @@ settings_meeting_time_selector_constructed (GObject *object)
 	g_object_unref (settings);
 
 	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (e_settings_meeting_time_selector_parent_class)->
-		constructed (object);
+	G_OBJECT_CLASS (e_settings_meeting_time_selector_parent_class)->constructed (object);
 }
 
 static void
