@@ -67,8 +67,7 @@ settings_web_view_constructed (GObject *object)
 	g_object_unref (settings);
 
 	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (e_settings_web_view_parent_class)->
-		constructed (object);
+	G_OBJECT_CLASS (e_settings_web_view_parent_class)->constructed (object);
 }
 
 static void
