@@ -303,7 +303,7 @@ userstring_to_systemstring (const gchar *userstring)
 static void
 do_save_calendar_csv (FormatHandler *handler,
                       ESourceSelector *selector,
-                      ECalClientSourceType type,
+		      EClientCache *client_cache,
                       gchar *dest_uri)
 {
 
@@ -331,8 +331,8 @@ do_save_calendar_csv (FormatHandler *handler,
 
 	/* open source client */
 	primary_source = e_source_selector_ref_primary_selection (selector);
-	source_client = e_cal_client_connect_sync (
-		primary_source, type, NULL, &error);
+	source_client = e_client_cache_get_client_sync (client_cache,
+		primary_source, e_source_selector_get_extension_name (selector), NULL, &error);
 	g_object_unref (primary_source);
 
 	/* Sanity check. */
