@@ -387,6 +387,11 @@ pk11_password (PK11SlotInfo *slot,
 
 	gboolean rv = FALSE;
 
+	/* For tokens with CKF_PROTECTED_AUTHENTICATION_PATH we
+	 * need to return a non-empty but unused password */
+	if (PK11_ProtectedAuthenticationPath(slot))
+		return PORT_Strdup("");
+
 	g_signal_emit (
 		e_cert_db_peek (),
 		e_cert_db_signals[PK11_PASSWD], 0,
@@ -1094,6 +1099,7 @@ e_cert_db_import_certs_from_file (ECertDB *cert_db,
 			rv = e_cert_db_import_email_cert (cert_db, buf, bytes_read, imported_certs, error);
 			break;
 
+		/* coverity[dead_error_begin] */
 		default:
 			rv = FALSE;
 			break;
